svn commit: trunk/uClibc: extra/scripts

psm at uclibc.org psm at uclibc.org
Thu Nov 17 21:50:00 UTC 2005


Author: psm
Date: 2005-11-17 13:49:59 -0800 (Thu, 17 Nov 2005)
New Revision: 12389

Log:
Replace TOPDIR w/ top_builddir

Modified:
   trunk/uClibc/Makefile.in
   trunk/uClibc/extra/scripts/gen_bits_syscall_h.sh


Changeset:
Modified: trunk/uClibc/Makefile.in
===================================================================
--- trunk/uClibc/Makefile.in	2005-11-17 21:43:58 UTC (rev 12388)
+++ trunk/uClibc/Makefile.in	2005-11-17 21:49:59 UTC (rev 12389)
@@ -96,7 +96,7 @@
 	@cd $(top_builddir); \
 	set -e; \
 	$(SHELL_SET_X); \
-	TOPDIR=. CC="$(CC)" /bin/sh extra/scripts/gen_bits_syscall_h.sh > include/bits/sysnum.h.new; \
+	top_builddir=. CC="$(CC)" /bin/sh extra/scripts/gen_bits_syscall_h.sh > include/bits/sysnum.h.new; \
 	if cmp include/bits/sysnum.h include/bits/sysnum.h.new >/dev/null 2>&1; then \
 		$(RM) include/bits/sysnum.h.new; \
 	else \

Modified: trunk/uClibc/extra/scripts/gen_bits_syscall_h.sh
===================================================================
--- trunk/uClibc/extra/scripts/gen_bits_syscall_h.sh	2005-11-17 21:43:58 UTC (rev 12388)
+++ trunk/uClibc/extra/scripts/gen_bits_syscall_h.sh	2005-11-17 21:49:59 UTC (rev 12389)
@@ -8,14 +8,14 @@
 
 # June 27, 2001         Manuel Novoa III
 #
 # This script expects TOPDIR and CC (as used in the Makefiles) to be set in
 # the environment, and outputs the appropriate $TOPDIR/include/bits/sysnum.h
 # corresponding to $TOPDIR/include/asm/unistd.h to stdout.
 #
 # Warning!!! This does _no_ error checking!!!
 
-UNISTD_H_PATH=$TOPDIR/include/asm/unistd.h
-INCLUDE_OPTS="-I$TOPDIR/include"
+UNISTD_H_PATH=$top_builddir/include/asm/unistd.h
+INCLUDE_OPTS="-I$top_builddir/include"
 
 ( echo "#include \"$UNISTD_H_PATH\"" ;
   $CC -E -dN $INCLUDE_OPTS $UNISTD_H_PATH | # needed to strip out any kernel-internal defines
@@ -8,14 +8,14 @@
 # June 27, 2001         Manuel Novoa III
 #
-# This script expects TOPDIR and CC (as used in the Makefiles) to be set in
-# the environment, and outputs the appropriate $TOPDIR/include/bits/sysnum.h
-# corresponding to $TOPDIR/include/asm/unistd.h to stdout.
+# This script expects top_builddir and CC (as used in the Makefiles) to be set in
+# the environment, and outputs the appropriate $top_builddir/include/bits/sysnum.h
+# corresponding to $top_builddir/include/asm/unistd.h to stdout.
 #
 # Warning!!! This does _no_ error checking!!!




More information about the uClibc-cvs mailing list